==> zio-aws-sagemaker_2.12-5.17.112.1-sources.jar: zio/aws/sagemaker/model/IntegerParameterRange.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.sagemaker.model.primitives.{ParameterValue, ParameterKey}
import scala.jdk.CollectionConverters._
final case class IntegerParameterRange(
    name: ParameterKey,
    minValue: ParameterValue,
    maxValue: ParameterValue,
    scalingType: Option[zio.aws.sagemaker.model.HyperParameterScalingType] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange = {
    import IntegerParameterRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
      .builder()
      .name(ParameterKey.unwrap(name): java.lang.String)
      .minValue(ParameterValue.unwrap(minValue): java.lang.String)
      .maxValue(ParameterValue.unwrap(maxValue): java.lang.String)
      .optionallyWith(scalingType.map(value => value.unwrap))(_.scalingType)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly =
    zio.aws.sagemaker.model.IntegerParameterRange.wrap(buildAwsValue())
}
object IntegerParameterRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.IntegerParameterRange =
      zio.aws.sagemaker.model.IntegerParameterRange(
        name,
        minValue,
        maxValue,
        scalingType.map(value => value)
      )
    def name: ParameterKey
    def minValue: ParameterValue
    def maxValue: ParameterValue
    def scalingType: Option[zio.aws.sagemaker.model.HyperParameterScalingType]
    def getName: ZIO[Any, Nothing, ParameterKey] = ZIO.succeed(name)
    def getMinValue: ZIO[Any, Nothing, ParameterValue] = ZIO.succeed(minValue)
    def getMaxValue: ZIO[Any, Nothing, ParameterValue] = ZIO.succeed(maxValue)
    def getScalingType: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.HyperParameterScalingType
    ] = AwsError.unwrapOptionField("scalingType", scalingType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ) extends zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly {
    override val name: ParameterKey =
      zio.aws.sagemaker.model.primitives.ParameterKey(impl.name())
    override val minValue: ParameterValue =
      zio.aws.sagemaker.model.primitives.ParameterValue(impl.minValue())
    override val maxValue: ParameterValue =
      zio.aws.sagemaker.model.primitives.ParameterValue(impl.maxValue())
    override val scalingType
        : Option[zio.aws.sagemaker.model.HyperParameterScalingType] = scala
      .Option(impl.scalingType())
      .map(value =>
        zio.aws.sagemaker.model.HyperParameterScalingType.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ): zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly = new Wrapper(impl)
}

==> zio-aws-sagemaker_2.12-5.17.168.1-sources.jar: zio/aws/sagemaker/model/IntegerParameterRange.scala <==
package zio.aws.sagemaker.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.sagemaker.model.primitives.{ParameterValue, ParameterKey}
import scala.jdk.CollectionConverters._
final case class IntegerParameterRange(
    name: ParameterKey,
    minValue: ParameterValue,
    maxValue: ParameterValue,
    scalingType: Optional[zio.aws.sagemaker.model.HyperParameterScalingType] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange = {
    import IntegerParameterRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
      .builder()
      .name(ParameterKey.unwrap(name): java.lang.String)
      .minValue(ParameterValue.unwrap(minValue): java.lang.String)
      .maxValue(ParameterValue.unwrap(maxValue): java.lang.String)
      .optionallyWith(scalingType.map(value => value.unwrap))(_.scalingType)
      .build()
  }
  def asReadOnly: zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly =
    zio.aws.sagemaker.model.IntegerParameterRange.wrap(buildAwsValue())
}
object IntegerParameterRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.sagemaker.model.IntegerParameterRange =
      zio.aws.sagemaker.model.IntegerParameterRange(
        name,
        minValue,
        maxValue,
        scalingType.map(value => value)
      )
    def name: ParameterKey
    def minValue: ParameterValue
    def maxValue: ParameterValue
    def scalingType: Optional[zio.aws.sagemaker.model.HyperParameterScalingType]
    def getName: ZIO[Any, Nothing, ParameterKey] = ZIO.succeed(name)
    def getMinValue: ZIO[Any, Nothing, ParameterValue] = ZIO.succeed(minValue)
    def getMaxValue: ZIO[Any, Nothing, ParameterValue] = ZIO.succeed(maxValue)
    def getScalingType: ZIO[
      Any,
      AwsError,
      zio.aws.sagemaker.model.HyperParameterScalingType
    ] = AwsError.unwrapOptionField("scalingType", scalingType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ) extends zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly {
    override val name: ParameterKey =
      zio.aws.sagemaker.model.primitives.ParameterKey(impl.name())
    override val minValue: ParameterValue =
      zio.aws.sagemaker.model.primitives.ParameterValue(impl.minValue())
    override val maxValue: ParameterValue =
      zio.aws.sagemaker.model.primitives.ParameterValue(impl.maxValue())
    override val scalingType
        : Optional[zio.aws.sagemaker.model.HyperParameterScalingType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.scalingType())
        .map(value =>
          zio.aws.sagemaker.model.HyperParameterScalingType.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.sagemaker.model.IntegerParameterRange
  ): zio.aws.sagemaker.model.IntegerParameterRange.ReadOnly = new Wrapper(impl)
}
